@@ -836,7 +836,10 @@ class Document(dict):
             raise AttributeError(u'Field %s is undefined in this document' % name)
 
     def __setattr__(self, name, value):
-        self[name] = value
+        if name == '_db':
+            super(mydict, self).__setattr__(name, value)
+        else:
+            self[name] = value
 
     def __delattr__(self, name):
         del(self[name])
@@ -845,7 +848,7 @@ class Document(dict):
         """Save document. Document will be saved to database ``db`` or ``document._db``"""
         
         db = db or getattr(self, '_db', None)
-        if db:
+        if not db is None:
             db[self.id] = self
         else:
             raise Exception('Can\'t save document - target database is undefined')
